==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/cognitiveservices/kotlin/RaiBlocklist.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.cognitiveservices.kotlin

import com.pulumi.azurenative.cognitiveservices.kotlin.outputs.RaiBlocklistPropertiesResponse
import com.pulumi.azurenative.cognitiveservices.kotlin.outputs.SystemDataResponse
import com.pulumi.core.Output
import com.pulumi.kotlin.KotlinCustomResource
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.ResourceMapper
import com.pulumi.kotlin.options.CustomResourceOptions
import com.pulumi.kotlin.options.CustomResourceOptionsBuilder
import com.pulumi.resources.Resource
import kotlin.Boolean
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.Map
import com.pulumi.azurenative.cognitiveservices.kotlin.outputs.RaiBlocklistPropertiesResponse.Companion.toKotlin as raiBlocklistPropertiesResponseToKotlin
import com.pulumi.azurenative.cognitiveservices.kotlin.outputs.SystemDataResponse.Companion.toKotlin as systemDataResponseToKotlin

/**
 * Builder for [RaiBlocklist].
 */
@PulumiTagMarker
public class RaiBlocklistResourceBuilder internal constructor() {
    public var name: String? = null

    public var args: RaiBlocklistArgs = RaiBlocklistArgs()

    public var opts: CustomResourceOptions = CustomResourceOptions()

    /**
     * @param name The _unique_ name of the resulting resource.
     */
    public fun name(`value`: String) {
        this.name = value
    }

    /**
     * @param block The arguments to use to populate this resource's properties.
     */
    public suspend fun args(block: suspend RaiBlocklistArgsBuilder.() -> Unit) {
        val builder = RaiBlocklistArgsBuilder()
        block(builder)
        this.args = builder.build()
    }

    /**
     * @param block A bag of options that control this resource's behavior.
     */
    public suspend fun opts(block: suspend CustomResourceOptionsBuilder.() -> Unit) {
        this.opts = com.pulumi.kotlin.options.opts(block)
    }

    internal fun build(): RaiBlocklist {
        val builtJavaResource =
            com.pulumi.azurenative.cognitiveservices.RaiBlocklist(
                this.name,
                this.args.toJava(),
                this.opts.toJava(),
            )
        return RaiBlocklist(builtJavaResource)
    }
}

/**
 * Cognitive Services RaiBlocklist.
 * Azure REST API version: 2023-10-01-preview.
 * ## Example Usage
 * ### PutRaiBlocklist
 * ```csharp
 * using System.Collections.Generic;
 * using System.Linq;
 * using Pulumi;
 * using AzureNative = Pulumi.AzureNative;
 * return await Deployment.RunAsync(() =>
 * {
 *     var raiBlocklist = new AzureNative.CognitiveServices.RaiBlocklist("raiBlocklist", new()
 *     {
 *         AccountName = "accountName",
 *         Properties = new AzureNative.CognitiveServices.Inputs.RaiBlocklistPropertiesArgs
 *         {
 *             Description = "Basic blocklist description",
 *         },
 *         RaiBlocklistName = "raiBlocklistName",
 *         ResourceGroupName = "resourceGroupName",
 *     });
 * });
 * ```
 * ```go
 * package main
 * import (
 * 	"github.com/pulumi/pulumi-azure-native-sdk/cognitiveservices/v2"
 * 	"github.com/pulumi/pulumi/sdk/v3/go/pulumi"
 * )
 * func main() {
 * 	pulumi.Run(func(ctx *pulumi.Context) error {
 * 		_, err := cognitiveservices.NewRaiBlocklist(ctx, "raiBlocklist", &cognitiveservices.RaiBlocklistArgs{
 * 			AccountName: pulumi.String("accountName"),
 * 			Properties: &cognitiveservices.RaiBlocklistPropertiesArgs{
 * 				Description: pulumi.String("Basic blocklist description"),
 * 			},
 * 			RaiBlocklistName:  pulumi.String("raiBlocklistName"),
 * 			ResourceGroupName: pulumi.String("resourceGroupName"),
 * 		})
 * 		if err != nil {
 * 			return err
 * 		}
 * 		return nil
 * 	})
 * }
 * ```
 * ```java
 * package generated_program;
 * import com.pulumi.Context;
 * import com.pulumi.Pulumi;
 * import com.pulumi.core.Output;
 * import com.pulumi.azurenative.cognitiveservices.RaiBlocklist;
 * import com.pulumi.azurenative.cognitiveservices.RaiBlocklistArgs;
 * import java.util.List;
 * import java.util.ArrayList;
 * import java.util.Map;
 * import java.io.File;
 * import java.nio.file.Files;
 * import java.nio.file.Paths;
 * public class App {
 *     public static void main(String[] args) {
 *         Pulumi.run(App::stack);
 *     }
 *     public static void stack(Context ctx) {
 *         var raiBlocklist = new RaiBlocklist("raiBlocklist", RaiBlocklistArgs.builder()
 *             .accountName("accountName")
 *             .properties(Map.of("description", "Basic blocklist description"))
 *             .raiBlocklistName("raiBlocklistName")
 *             .resourceGroupName("resourceGroupName")
 *             .build());
 *     }
 * }
 * ```
 * ## Import
 * An existing resource can be imported using its type token, name, and identifier, e.g.
 * ```sh
 * $ pulumi import azure-native:cognitiveservices:RaiBlocklist raiBlocklistName /subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.CognitiveServices/accounts/{accountName}/raiBlocklists/{raiBlocklistName}
 * ```
 */
public class RaiBlocklist internal constructor(
    override val javaResource: com.pulumi.azurenative.cognitiveservices.RaiBlocklist,
) : KotlinCustomResource(javaResource, RaiBlocklistMapper) {
    /**
     * Resource Etag.
     */
    public val etag: Output<String>
        get() = javaResource.etag().applyValue({ args0 -> args0 })

    /**
     * The name of the resource
     */
    public val name: Output<String>
        get() = javaResource.name().applyValue({ args0 -> args0 })

    /**
     * Properties of Cognitive Services RaiBlocklist.
     */
    public val properties: Output<RaiBlocklistPropertiesResponse>
        get() = javaResource.properties().applyValue({ args0 ->
            args0.let({ args0 ->
                raiBlocklistPropertiesResponseToKotlin(args0)
            })
        })

    /**
     * Metadata pertaining to creation and last modification of the resource.
     */
    public val systemData: Output<SystemDataResponse>
        get() = javaResource.systemData().applyValue({ args0 ->
            args0.let({ args0 ->
                systemDataResponseToKotlin(args0)
            })
        })

    /**
     * Resource tags.
     */
    public val tags: Output<Map<String, String>>?
        get() = javaResource.tags().applyValue({ args0 ->
            args0.map({ args0 ->
                args0.map({ args0 ->
                    args0.key.to(args0.value)
                }).toMap()
            }).orElse(null)
        })

    /**
     * The type of the resource. E.g. "Microsoft.Compute/virtualMachines" or "Microsoft.Storage/storageAccounts"
     */
    public val type: Output<String>
        get() = javaResource.type().applyValue({ args0 -> args0 })
}

public object RaiBlocklistMapper : ResourceMapper<RaiBlocklist> {
    override fun supportsMappingOfType(javaResource: Resource): Boolean =
        com.pulumi.azurenative.cognitiveservices.RaiBlocklist::class == javaResource::class

    override fun map(javaResource: Resource): RaiBlocklist = RaiBlocklist(
        javaResource as
            com.pulumi.azurenative.cognitiveservices.RaiBlocklist,
    )
}

/**
 * @see [RaiBlocklist].
 * @param name The _unique_ name of the resulting resource.
 * @param block Builder for [RaiBlocklist].
 */
public suspend fun raiBlocklist(
    name: String,
    block: suspend RaiBlocklistResourceBuilder.() -> Unit,
): RaiBlocklist {
    val builder = RaiBlocklistResourceBuilder()
    builder.name(name)
    block(builder)
    return builder.build()
}

/**
 * @see [RaiBlocklist].
 * @param name The _unique_ name of the resulting resource.
 */
public fun raiBlocklist(name: String): RaiBlocklist {
    val builder = RaiBlocklistResourceBuilder()
    builder.name(name)
    return builder.build()
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/cognitiveservices/kotlin/RaiBlocklist.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.cognitiveservices.kotlin

import com.pulumi.azurenative.cognitiveservices.kotlin.outputs.RaiBlocklistPropertiesResponse
import com.pulumi.azurenative.cognitiveservices.kotlin.outputs.SystemDataResponse
import com.pulumi.core.Output
import com.pulumi.kotlin.KotlinCustomResource
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.ResourceMapper
import com.pulumi.kotlin.options.CustomResourceOptions
import com.pulumi.kotlin.options.CustomResourceOptionsBuilder
import com.pulumi.resources.Resource
import kotlin.Boolean
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.Map
import com.pulumi.azurenative.cognitiveservices.kotlin.outputs.RaiBlocklistPropertiesResponse.Companion.toKotlin as raiBlocklistPropertiesResponseToKotlin
import com.pulumi.azurenative.cognitiveservices.kotlin.outputs.SystemDataResponse.Companion.toKotlin as systemDataResponseToKotlin

/**
 * Builder for [RaiBlocklist].
 */
@PulumiTagMarker
public class RaiBlocklistResourceBuilder internal constructor() {
    public var name: String? = null

    public var args: RaiBlocklistArgs = RaiBlocklistArgs()

    public var opts: CustomResourceOptions = CustomResourceOptions()

    /**
     * @param name The _unique_ name of the resulting resource.
     */
    public fun name(`value`: String) {
        this.name = value
    }

    /**
     * @param block The arguments to use to populate this resource's properties.
     */
    public suspend fun args(block: suspend RaiBlocklistArgsBuilder.() -> Unit) {
        val builder = RaiBlocklistArgsBuilder()
        block(builder)
        this.args = builder.build()
    }

    /**
     * @param block A bag of options that control this resource's behavior.
     */
    public suspend fun opts(block: suspend CustomResourceOptionsBuilder.() -> Unit) {
        this.opts = com.pulumi.kotlin.options.CustomResourceOptions.opts(block)
    }

    internal fun build(): RaiBlocklist {
        val builtJavaResource =
            com.pulumi.azurenative.cognitiveservices.RaiBlocklist(
                this.name,
                this.args.toJava(),
                this.opts.toJava(),
            )
        return RaiBlocklist(builtJavaResource)
    }
}

/**
 * Cognitive Services RaiBlocklist.
 * Azure REST API version: 2023-10-01-preview.
 * ## Example Usage
 * ### PutRaiBlocklist
 * ```csharp
 * using System.Collections.Generic;
 * using System.Linq;
 * using Pulumi;
 * using AzureNative = Pulumi.AzureNative;
 * return await Deployment.RunAsync(() =>
 * {
 *     var raiBlocklist = new AzureNative.CognitiveServices.RaiBlocklist("raiBlocklist", new()
 *     {
 *         AccountName = "accountName",
 *         Properties = new AzureNative.CognitiveServices.Inputs.RaiBlocklistPropertiesArgs
 *         {
 *             Description = "Basic blocklist description",
 *         },
 *         RaiBlocklistName = "raiBlocklistName",
 *         ResourceGroupName = "resourceGroupName",
 *     });
 * });
 * ```
 * ```go
 * package main
 * import (
 * 	"github.com/pulumi/pulumi-azure-native-sdk/cognitiveservices/v2"
 * 	"github.com/pulumi/pulumi/sdk/v3/go/pulumi"
 * )
 * func main() {
 * 	pulumi.Run(func(ctx *pulumi.Context) error {
 * 		_, err := cognitiveservices.NewRaiBlocklist(ctx, "raiBlocklist", &cognitiveservices.RaiBlocklistArgs{
 * 			AccountName: pulumi.String("accountName"),
 * 			Properties: &cognitiveservices.RaiBlocklistPropertiesArgs{
 * 				Description: pulumi.String("Basic blocklist description"),
 * 			},
 * 			RaiBlocklistName:  pulumi.String("raiBlocklistName"),
 * 			ResourceGroupName: pulumi.String("resourceGroupName"),
 * 		})
 * 		if err != nil {
 * 			return err
 * 		}
 * 		return nil
 * 	})
 * }
 * ```
 * ```java
 * package generated_program;
 * import com.pulumi.Context;
 * import com.pulumi.Pulumi;
 * import com.pulumi.core.Output;
 * import com.pulumi.azurenative.cognitiveservices.RaiBlocklist;
 * import com.pulumi.azurenative.cognitiveservices.RaiBlocklistArgs;
 * import com.pulumi.azurenative.cognitiveservices.inputs.RaiBlocklistPropertiesArgs;
 * import java.util.List;
 * import java.util.ArrayList;
 * import java.util.Map;
 * import java.io.File;
 * import java.nio.file.Files;
 * import java.nio.file.Paths;
 * public class App {
 *     public static void main(String[] args) {
 *         Pulumi.run(App::stack);
 *     }
 *     public static void stack(Context ctx) {
 *         var raiBlocklist = new RaiBlocklist("raiBlocklist", RaiBlocklistArgs.builder()
 *             .accountName("accountName")
 *             .properties(RaiBlocklistPropertiesArgs.builder()
 *                 .description("Basic blocklist description")
 *                 .build())
 *             .raiBlocklistName("raiBlocklistName")
 *             .resourceGroupName("resourceGroupName")
 *             .build());
 *     }
 * }
 * ```
 * ## Import
 * An existing resource can be imported using its type token, name, and identifier, e.g.
 * ```sh
 * $ pulumi import azure-native:cognitiveservices:RaiBlocklist raiBlocklistName /subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.CognitiveServices/accounts/{accountName}/raiBlocklists/{raiBlocklistName}
 * ```
 */
public class RaiBlocklist internal constructor(
    override val javaResource: com.pulumi.azurenative.cognitiveservices.RaiBlocklist,
) : KotlinCustomResource(javaResource, RaiBlocklistMapper) {
    /**
     * Resource Etag.
     */
    public val etag: Output<String>
        get() = javaResource.etag().applyValue({ args0 -> args0 })

    /**
     * The name of the resource
     */
    public val name: Output<String>
        get() = javaResource.name().applyValue({ args0 -> args0 })

    /**
     * Properties of Cognitive Services RaiBlocklist.
     */
    public val properties: Output<RaiBlocklistPropertiesResponse>
        get() = javaResource.properties().applyValue({ args0 ->
            args0.let({ args0 ->
                raiBlocklistPropertiesResponseToKotlin(args0)
            })
        })

    /**
     * Metadata pertaining to creation and last modification of the resource.
     */
    public val systemData: Output<SystemDataResponse>
        get() = javaResource.systemData().applyValue({ args0 ->
            args0.let({ args0 ->
                systemDataResponseToKotlin(args0)
            })
        })

    /**
     * Resource tags.
     */
    public val tags: Output<Map<String, String>>?
        get() = javaResource.tags().applyValue({ args0 ->
            args0.map({ args0 ->
                args0.map({ args0 ->
                    args0.key.to(args0.value)
                }).toMap()
            }).orElse(null)
        })

    /**
     * The type of the resource. E.g. "Microsoft.Compute/virtualMachines" or "Microsoft.Storage/storageAccounts"
     */
    public val type: Output<String>
        get() = javaResource.type().applyValue({ args0 -> args0 })
}

public object RaiBlocklistMapper : ResourceMapper<RaiBlocklist> {
    override fun supportsMappingOfType(javaResource: Resource): Boolean =
        com.pulumi.azurenative.cognitiveservices.RaiBlocklist::class == javaResource::class

    override fun map(javaResource: Resource): RaiBlocklist = RaiBlocklist(
        javaResource as
            com.pulumi.azurenative.cognitiveservices.RaiBlocklist,
    )
}

/**
 * @see [RaiBlocklist].
 * @param name The _unique_ name of the resulting resource.
 * @param block Builder for [RaiBlocklist].
 */
public suspend fun raiBlocklist(
    name: String,
    block: suspend RaiBlocklistResourceBuilder.() -> Unit,
): RaiBlocklist {
    val builder = RaiBlocklistResourceBuilder()
    builder.name(name)
    block(builder)
    return builder.build()
}

/**
 * @see [RaiBlocklist].
 * @param name The _unique_ name of the resulting resource.
 */
public fun raiBlocklist(name: String): RaiBlocklist {
    val builder = RaiBlocklistResourceBuilder()
    builder.name(name)
    return builder.build()
}
